@@ -23,9 +23,9 @@ class flowDerivativesTab(QWidget):
         self.derivativeLabel = QLabel("Derivative type")
         self.derivativeLayout.addWidget(self.derivativeLabel, 0, 0)
         self.derivativeComboBox = QComboBox()
-        self.derivativeList = {"Vorticity": np.array([[1, 0], [0, -1]]),
-                               "Divergence": np.array([[1, 0], [0, 1]]),
-                               "Simple Shear": np.array([[0, 1], [1, 0]])}
+        self.derivativeList = {"Vorticity": np.array([[-1, 0], [0, 1]]),
+                               "Divergence": np.array([[0, 1], [1, 0]]),
+                               "Simple Shear": np.array([[1, 0], [0, 1]])}
         self.derivativeComboBox.addItems(list(self.derivativeList.keys()))
         self.derivativeLayout.addWidget(self.derivativeComboBox, 0, 1)
         self.derivativeLayout.setColumnStretch(1, 10)
@@ -65,11 +65,11 @@ class flowDerivativesTab(QWidget):
 
         self.layout.addStretch()
 
-        self.processButton = QPushButton("Plot derivative")
+        self.processButton = QPushButton("Process FlowDerivative")
         self.processButton.setEnabled(False)
         self.buttons = QHBoxLayout()
         self.buttons.addWidget(self.processButton)
-        self.displayOutput = QPushButton("Display output")
+        self.displayOutput = QPushButton("Display FlowDerivative")
         self.displayOutput.setEnabled(False)
         self.buttons.addWidget(self.displayOutput)
         self.displayColorWheel = QPushButton("Display colour map")
@@ -121,7 +121,7 @@ class flowDerivativesTab(QWidget):
     def updateToProcessButton(self):
         print("Calculation has been stopped")
         self.processButton.setStyleSheet(start_button_stylesheet)
-        self.processButton.setText("Process flow derivatives")
+        self.processButton.setText("Process FlowDerivative")
         self.thread.quit()
 
     def updateColormapOptions(self):
