@@ -109,7 +109,7 @@ class flowTracerTab(QWidget):
     def updateToProcessButton(self):
         print("Calculation has been stopped")
         self.processButton.setStyleSheet(start_button_stylesheet)
-        self.processButton.setText("Generate Flowtracer")
+        self.processButton.setText("Generate FlowTracer")
         self.nextButton.setEnabled(True)
         self.thread.quit()
 
@@ -174,19 +174,26 @@ class flowTracerTab(QWidget):
             self.messageSignal.emit("FlowTracer can only be performed when the forward velocity field folder is defined.", "warn")
             self.messageSignal.emit("Please ensure this folder is loaded under the 'Load velocity field' tab.", "warn")
             self.processButton.setEnabled(False)
+        if self.config.segmentationFolderPath is None and self.randomTracersComboBox.currentText() == self.tracerMethods[2]:
+            self.messageSignal.emit("FlowTracer with the 'Object centroids' option can only be performed when the object segmentation folder is defined.", "warn")
+            self.messageSignal.emit("Please ensure this folder is loaded under the 'Load velocity field' tab.", "warn")
+            self.processButton.setEnabled(False)
         else:
             self.processButton.setEnabled(True)
 
     def updateTracerGeneration(self):
         if self.randomTracersComboBox.currentText() == self.tracerMethods[0]:
+            self.onFocusUpdate()
             self.tracerNumLineEdit.setEnabled(True)
             self.spacingLineEdit.setEnabled(False)
             self.config.use_random_tracers = True
         elif self.randomTracersComboBox.currentText() == self.tracerMethods[1]:
+            self.onFocusUpdate()
             self.tracerNumLineEdit.setEnabled(False)
             self.spacingLineEdit.setEnabled(True)
             self.config.use_random_tracers = False
         elif self.randomTracersComboBox.currentText() == self.tracerMethods[2]:
+            self.onFocusUpdate()
             self.tracerNumLineEdit.setEnabled(False)
             self.spacingLineEdit.setEnabled(False)
             self.config.use_random_tracers = False
