@@ -228,7 +228,7 @@ class opFlowLabWorker(QObject):
             self.progressSignal.emit(int((100 * (img_no+1)) / (instance.length-1)))
 
             print("Updating instance with FlowMatch velocity flows")
-            self.config.forwardFolderPath = os.path.join(self.config.mainFolderPath, self.config.flowMatch_folder)
+            self.config.forwardFolderPath = os.path.join(self.config.mainFolderPath, self.config.flowMatch_folder).replace(os.sep, '/')
             instance.initialize_forward_velocities(self.config.forwardFolderPath)
             self.updateSignal.emit()
         finally:
