@@ -5,7 +5,6 @@ import sys
 import warnings
 
 import cv2
-import matplotlib.pyplot as plt
 import numpy as np
 import skimage.color
 import skimage.filters
@@ -60,6 +59,20 @@ class OpFlowLab:
         # TODO: Perform checks to ensure that all the filelists are of the correct length
 
     def parse_folder(self, folder):
+        """
+        Appends the main folder director to the folder name given
+
+        Parameters
+        ----------
+        folder : str
+            Name of folder
+
+        Returns
+        -------
+        folder : str
+            Full path string containing the main folder path along with the provided folder
+
+        """
         if os.path.isdir(folder):
             pass
         else:
@@ -67,6 +80,22 @@ class OpFlowLab:
         return folder
 
     def initialize_forward_velocities(self, folder, velocity_type=None, velocity_ext_type=None):
+        """
+        Initializes the internal folder path and file lists for the forward velocities
+
+        Parameters
+        ----------
+        folder : str
+            Either full path of the directory or the name of the folder in the main path
+        velocity_type : str or None
+            Specify if the velocity field is a dense or sparse velocity field
+        velocity_ext_type : str or None
+            Specify the extension of file containing the velocity field
+
+        Returns
+        -------
+
+        """
         if velocity_type is None:
             velocity_type = self.velocity_type
         if velocity_ext_type is None:
@@ -78,6 +107,22 @@ class OpFlowLab:
                                                                       reverse_sort=False)
 
     def initialize_reverse_velocities(self, folder, velocity_type=None, velocity_ext_type=None):
+        """
+        Initializes the internal folder path and file lists for the forward velocities
+
+        Parameters
+        ----------
+        folder : str
+            Either full path of the directory or the name of the folder in the main path
+        velocity_type : str or None
+            Specify if the velocity field is a dense or sparse velocity field
+        velocity_ext_type : str or None
+            Specify the extension of file containing the velocity field
+
+        Returns
+        -------
+
+        """
         if velocity_type is None:
             velocity_type = self.velocity_type
         if velocity_ext_type is None:
@@ -89,6 +134,20 @@ class OpFlowLab:
                                                                       reverse_sort=True)
 
     def initialize_segmentation_folder(self, folder, img_ext_type=None):
+        """
+        Initializes the internal folder path and file lists for the segmented images
+
+        Parameters
+        ----------
+        folder : str
+            Either full path of the directory or the name of the folder in the main path
+        img_ext_type : str or None
+            Specify the extension of the image file
+
+        Returns
+        -------
+
+        """
         if img_ext_type is None:
             img_ext_type = self.image_ext_type
         self.object_segmentation_folder = self.parse_folder(folder)
@@ -136,7 +195,7 @@ class OpFlowLab:
             x_pos, y_pos = np.meshgrid(np.arange(self.image_shape[1]), np.arange(self.image_shape[0]))
             pts = np.array(np.c_[y_pos.ravel(), x_pos.ravel()], dtype=np.float32)
             distances, indices = tree.query(pts, k=5, distance_upper_bound=32.0)
-            pts = np.rint(pts).astype(np.int)
+            pts = np.rint(pts).astype(np.int32)
 
             coords = np.c_[velocity_y.ravel(), velocity_x.ravel()]
             piv_x_interpolate = np.zeros(self.image_shape)
@@ -152,7 +211,7 @@ class OpFlowLab:
                            min_object_size=None, max_object_size=None,
                            ):
         """
-        Wrapper function that calls :func:`~object_matching_iteration` for each individual pair of frames in the
+        Wrapper function that calls :func:`~flowMatch_iteration` for each individual pair of frames in the
         image stack.
 
         Parameters
@@ -160,7 +219,7 @@ class OpFlowLab:
         output_folder : str
             Folder name that will be created in the main directory to store the interpolated vector fields
         pairwise_threshold_distance : int
-            Distance between the propagated centroid location and the actual centroid location that is used as a cutoff for object matching
+            Distance between the propagated centroid location and the actual centroid location that is used as a cutoff for flowMatch
         min_object_size : int or None
             Minimum object size for it to be included in the matching process. Set to None to ignore this cutoff
         max_object_size : int or None
@@ -175,7 +234,7 @@ class OpFlowLab:
 
         See Also
         --------
-        object_matching_iteration: function used to perform object matching and interpolation for a single frame
+        flowMatch_iteration: function used to perform flowMatch for a single frame
         """
         # create output folders
         flowx_output_directory = os.path.join(self.main_folder, output_folder, 'flowx')
@@ -209,7 +268,7 @@ class OpFlowLab:
                             save_velocity_as_tif=False,
                             ):
         """
-        Perform object matching of segmented objects using the provided motion estimation vector information for a
+        Perform flowMatch of segmented objects using the provided motion estimation vector information for a
         single iteration and outputs an interpolated vector field using the velocity obtained from the matched objects.
 
         Parameters
@@ -241,10 +300,8 @@ class OpFlowLab:
 
         See Also
         --------
-        object_matching_function : wrapper function to perform object matching and interpolation on all frames
-        """
-        import copy
 
+        """
         # obtain initial centroids
         initial_image = skimage.io.imread(self.object_segmentation_filelist[frame_no])
         if initial_image.shape != self.image_shape:
@@ -302,7 +359,7 @@ class OpFlowLab:
 
         forward_pair_list = object_matching.get_pairs(initial_properties, remapped_target_image)
         forward_pair_list = forward_pair_list[~np.isnan(forward_pair_list)]
-        forward_pair_list = forward_pair_list.astype(np.int)
+        forward_pair_list = forward_pair_list.astype(np.int32)
 
         remap_x, remap_y = interpolation.inverse_mapping(forward_velocity_x, forward_velocity_y, self.image_shape)
         remapped_initial_image = cv2.remap(initial_image, remap_x.astype(np.float32), remap_y.astype(np.float32),
@@ -310,7 +367,7 @@ class OpFlowLab:
 
         reverse_pair_list = object_matching.get_pairs(target_properties, remapped_initial_image)
         reverse_pair_list = reverse_pair_list[~np.isnan(reverse_pair_list)]
-        reverse_pair_list = reverse_pair_list.astype(np.int)
+        reverse_pair_list = reverse_pair_list.astype(np.int32)
 
         forward_unique, forward_index, forward_bincount = np.unique(forward_pair_list, return_index=True,
                                                                     return_counts=True)
@@ -319,8 +376,8 @@ class OpFlowLab:
 
         diff_search = np.max(target_image) - len(target_properties)
 
-        selected_initial_mask = np.ones(len(initial_properties), np.bool)
-        selected_target_mask = np.ones(len(target_properties), np.bool)
+        selected_initial_mask = np.ones(len(initial_properties), np.bool8)
+        selected_target_mask = np.ones(len(target_properties), np.bool8)
 
         matched_flow_x, matched_flow_y, selected_initial_mask, selected_target_mask = object_matching.calculate_matched_velocities(
             initial_properties,
@@ -352,8 +409,8 @@ class OpFlowLab:
         reverse_velocity_x_smooth = skimage.filters.gaussian(reverse_velocity_x, 15, preserve_range=True)
         reverse_velocity_y_smooth = skimage.filters.gaussian(reverse_velocity_y, 15, preserve_range=True)
 
-        selected_initial_mask = np.ones(len(unselected_initial), np.bool)
-        selected_target_mask = np.ones(len(unselected_target), np.bool)
+        selected_initial_mask = np.ones(len(unselected_initial), np.bool8)
+        selected_target_mask = np.ones(len(unselected_target), np.bool8)
 
         # perform backward propagation of target centroids
         forward_propagated_centroids = tracer_functions.update_tracer(unselected_initial, forward_velocity_y_smooth,
@@ -381,7 +438,7 @@ class OpFlowLab:
                                                                                  target_properties[target_index])
 
                 if coords is not None:
-                    coords = np.rint(coords).astype(np.int)
+                    coords = np.rint(coords).astype(np.int32)
                     matched_flow_x[coords[:, 0], coords[:, 1]] = output_velocity[:, 1]
                     matched_flow_y[coords[:, 0], coords[:, 1]] = output_velocity[:, 0]
 
@@ -395,7 +452,7 @@ class OpFlowLab:
                                                                                  target_properties[target_index])
 
                 if coords is not None:
-                    coords = np.rint(coords).astype(np.int)
+                    coords = np.rint(coords).astype(np.int32)
                     matched_flow_x[coords[:, 0], coords[:, 1]] = output_velocity[:, 1]
                     matched_flow_y[coords[:, 0], coords[:, 1]] = output_velocity[:, 0]
 
@@ -423,8 +480,8 @@ class OpFlowLab:
             pairs = np.sum(difference_mask, axis=0)
             indices = np.where(pairs == 1)[0]
 
-            selected_initial_mask = np.ones(len(unselected_initial2), np.bool)
-            selected_target_mask = np.ones(len(unselected_target2), np.bool)
+            selected_initial_mask = np.ones(len(unselected_initial2), np.bool8)
+            selected_target_mask = np.ones(len(unselected_target2), np.bool8)
 
             for target_index in indices:
                 initial_index = np.where(difference_mask[:, target_index] == 1)[0][0]
@@ -432,7 +489,7 @@ class OpFlowLab:
                                                                                  target_properties[target_index])
 
                 if coords is not None:
-                    coords = np.rint(coords).astype(np.int)
+                    coords = np.rint(coords).astype(np.int32)
                     matched_flow_x[coords[:, 0], coords[:, 1]] = output_velocity[:, 1]
                     matched_flow_y[coords[:, 0], coords[:, 1]] = output_velocity[:, 0]
 
@@ -452,8 +509,8 @@ class OpFlowLab:
             pairs = np.sum(difference_mask, axis=1)
             indices = np.where(pairs == 1)[0]
 
-            selected_initial_mask = np.ones(len(unselected_initial2), np.bool)
-            selected_target_mask = np.ones(len(unselected_target2), np.bool)
+            selected_initial_mask = np.ones(len(unselected_initial2), np.bool8)
+            selected_target_mask = np.ones(len(unselected_target2), np.bool8)
 
             for initial_index in indices:
                 target_index = np.where(difference_mask[initial_index, :] == 1)[0][0]
@@ -461,7 +518,7 @@ class OpFlowLab:
                                                                                  target_properties[target_index])
 
                 if coords is not None:
-                    coords = np.rint(coords).astype(np.int)
+                    coords = np.rint(coords).astype(np.int32)
                     matched_flow_x[coords[:, 0], coords[:, 1]] = output_velocity[:, 1]
                     matched_flow_y[coords[:, 0], coords[:, 1]] = output_velocity[:, 0]
 
@@ -498,7 +555,7 @@ class OpFlowLab:
 
         values = np.c_[flow_y_cen, flow_x_cen]
 
-        matched_flow_x, matched_flow_y = interpolation.inverse_distance_weighting(pts.astype(np.int),
+        matched_flow_x, matched_flow_y = interpolation.inverse_distance_weighting(pts.astype(np.int32),
                                                                                   distances, indices,
                                                                                   values,
                                                                                   matched_flow_x,
@@ -520,6 +577,21 @@ class OpFlowLab:
                           output_folder="FlowWarp",
                           start_frame=0,
                           ):
+        """
+        Wrapper function that calls :func:`~flowWarp_iteration` for each individual pair of frames in the
+        image stack.
+
+        Parameters
+        ----------
+        output_folder : str
+            Folder name that will be created in the main directory to store the interpolated vector fields
+        start_frame : int
+            Specify the starting frame to calculate flowWarp
+
+        See Also
+        --------
+        flowWarp_iteration: function used to perform flowWarp for a single frame
+        """
         transformation_folder = os.path.join(self.forward_velocity_folder, output_folder)
         os.makedirs(transformation_folder, exist_ok=True)
 
@@ -529,6 +601,28 @@ class OpFlowLab:
     def flowWarp_iteration(self,
                            frame_no,
                            transformation_folder):
+        """
+        Performs flowWarp of an image using the calculated velocity field for that image and calculate the normalised
+        root mean squared error between it and the next image in the sequence.
+
+        Parameters
+        ----------
+        frame_no : int
+            Frame number with which to load vector
+        transformation_folder : str
+            Path to folder that will be used to store the x component of the interpolated vector field
+
+        Returns
+        -------
+        nrmse : int
+            Returns the normalized root mean square error between the warped image and the ground truth image
+        output_image : int
+            Returns the warped image
+
+        See Also
+        --------
+
+        """
         flow_x, flow_y = self.load_velocities(self.forward_velocity_filelist, frame_no)
         img_frame = self.image[frame_no]
 
@@ -554,7 +648,7 @@ class OpFlowLab:
                           max_tracers=None,
                           ):
         """
-        Wrapper function that calls :func:`~flow_path_iteration` for each frames in the image stack.
+        Wrapper function that calls :func:`~flowPath_iteration` for each frames in the image stack.
 
         Parameters
         ----------
@@ -564,6 +658,8 @@ class OpFlowLab:
             Frame number with which to start vector trace visualization
         frames : int
             Length of trails in number of frames that will be drawn for each artificial tracer
+        alpha : int
+            Specifies the alpha value for the flowPath overlay over the original image
         spacing : int
             Grid spacing used to initialize tracers
         max_tracers : int or None
@@ -626,8 +722,7 @@ class OpFlowLab:
 
         See Also
         --------
-        initialize_flow_path : function used to initialize tracers
-        flow_path_iteration: function used to perform vector trace visualization for a single frame
+        flowPath_iteration: function used to perform vector trace visualization for a single frame
         """
         if max_tracers is None:
             max_tracers = self.image_shape[0] * self.image_shape[1]
@@ -659,7 +754,7 @@ class OpFlowLab:
                            metric_type="angle",
                            ):
         """
-        Calculates and outputs vector traces for a single iteration
+        Calculates and outputs the flowPath for a single iteration based on the estimated velocity field.
 
         Parameters
         ----------
@@ -673,10 +768,18 @@ class OpFlowLab:
             Tuple containing the shape of the grid used to generate tracers
         flow_trace_folder : str
             Folder name that will be created in the main directory to store the vector trace images
+        alpha : int
+            Specifies the alpha value for the flowPath overlay over the original image
         frames : int
             Length of trails in number of frames that will be drawn for each artificial tracer
         spacing : int
             Grid spacing used to initialize tracers
+        colormap : Colormap, str, or None
+            Colormap to be used to colorize the flowPaths
+        colormap_min, colormap_max : float
+            Minimum and/or maximum value that is used to determine the normalization of the colormap
+        metric_type : str
+            Type of metric that is used to colorize the flowPaths
 
         Returns
         -------
@@ -687,8 +790,7 @@ class OpFlowLab:
 
         See Also
         --------
-        initialize_flow_path : function used to initialize tracers
-        plot_flow_path: wrapper function to perform vector trace visualization on all frames
+        flowPath_initialization : function used to initialize tracers
         """
         # load velocity
         flow_x, flow_y = self.load_velocities(self.forward_velocity_filelist, frame_no)
@@ -706,7 +808,7 @@ class OpFlowLab:
         # Identify empty locations
         filled_pos = tracer_pos[:(frames // 2), ...][~np.all(np.isnan(tracer_pos[:(frames // 2), ...]), axis=2)]
         filled_pos = np.floor_divide(filled_pos, spacing)
-        filled_index = np.ravel_multi_index(np.array(filled_pos, dtype=np.int).T, x_array_shape, mode='clip')
+        filled_index = np.ravel_multi_index(np.array(filled_pos, dtype=np.int32).T, x_array_shape, mode='clip')
         diff_index = np.setdiff1d(all_pos_index, filled_index)
 
         # fill in additional tracers
@@ -748,7 +850,7 @@ class OpFlowLab:
         for i in range(0, draw_tracer_pos.shape[1], 1):
             points = draw_tracer_pos[np.newaxis, :, i, ::-1]  # opencv takes (x,y)
             nan_pos = np.all(~np.isnan(points), axis=-1)
-            points = np.array(points[np.newaxis, nan_pos, :], dtype=np.int)
+            points = np.array(points[np.newaxis, nan_pos, :], dtype=np.int32)
             output_image = cv2.polylines(output_image, points, isClosed=False, color=colors[i, :3] * 255)
 
         skimage.io.imsave(os.path.join(flow_trace_folder, 'output_{:03d}.tif'.format(frame_no)), output_image,
@@ -756,10 +858,10 @@ class OpFlowLab:
 
         if colormap_type == "wheel":
             colormap_vis = colormap_functions.save_colorwheel(_colormap,
-                                                              filename=os.path.join(flow_trace_folder, "colorwheel_{:03d}.png".format(frame_no)),)
+                                                              filepath=os.path.join(flow_trace_folder, "colorwheel_{:03d}.png".format(frame_no)), )
         elif colormap_type == "bar":
             colormap_vis = colormap_functions.save_colorbar(_colormap,
-                                                            filename=os.path.join(flow_trace_folder, "colorbar_{:03d}.png".format(frame_no)),
+                                                            filepath=os.path.join(flow_trace_folder, "colorbar_{:03d}.png".format(frame_no)),
                                                             colormap_min=colormap_min, colormap_max=colormap_max, )
 
         return tracer_pos, output_image, colormap_vis
@@ -838,6 +940,9 @@ class OpFlowLab:
             Grid spacing used to initialize tracers.
         tracer_no : int or None
             Maximum number of tracers to be used in the calculation [Currently unused]
+        segmentation_filelist : list
+            List containing the segmented images. Used for setting the location of the intial flowTracers to the center
+            of the segmented objects.
 
         Returns
         -------
@@ -850,8 +955,7 @@ class OpFlowLab:
 
         See Also
         --------
-        initialize_flow_path : function used to initialize tracers
-        flow_path_iteration: function used to perform vector trace visualization for a single frame
+
         """
         if segmentation_filelist is not None:
             initial_image = skimage.io.imread(self.object_segmentation_filelist[0])
@@ -896,6 +1000,29 @@ class OpFlowLab:
                                tracer_folder,
                                frame_no, tracer_centroids, color,
                                ):
+        """
+        Plots and draws the position of the tracers in the first frame
+
+        Parameters
+        ----------
+        tracer_folder : str
+            Folder name that will be created in the main directory to store the flowTracer images
+        frame_no : int
+            Frame number with which to perform vector trace visualization
+        tracer_centroids : 3D array of shape (frames, tracer_no, 2)
+            Array containing the positions of the tracers in the format [y,x]
+        color : 2D array
+            Array containing the color information for each tracer
+
+        Returns
+        -------
+        output_image : 3D array of shape (m, n, 3)
+            RGB image showing the position of tracers
+
+        See Also
+        --------
+
+        """
         first_image = skimage.util.img_as_float32(utils.imadjust(self.image[frame_no, ...]))
         first_image = skimage.color.gray2rgb(first_image)
         output_image = tracer_functions.draw_tracer(first_image, tracer_centroids, color)
@@ -910,30 +1037,29 @@ class OpFlowLab:
                              frame_no, tracer_centroids, color,
                              ):
         """
-        Calculates and outputs vector traces for a single iteration
+        Calculates and outputs flowTracer for a single iteration
 
         Parameters
         ----------
+        tracer_folder : str
+            Folder name that will be created in the main directory to store the flowTracer images
         frame_no : int
             Frame number with which to perform vector trace visualization
         tracer_centroids : 3D array of shape (frames, tracer_no, 2)
             Array containing the positions of the tracers in the format [y,x]
         color : 2D array
             Array containing the color information for each tracer
-        tracer_folder : str
-            Folder name that will be created in the main directory to store the artificial tracer images
 
         Returns
         -------
         tracer_centroids : 3D array of shape (frames, tracer_no, 2)
             Array containing the positions of the tracers in the format [y,x]
         output_image : 3D array of shape (m, n, 3)
-            RGB image showing the tails of the tracers
+            RGB image showing the position of tracers
 
         See Also
         --------
-        initialize_flow_path : function used to initialize tracers
-        plot_flow_path: wrapper function to perform vector trace visualization on all frames
+        flowTracer_initialization : function used to initialize tracers
         """
         flow_x, flow_y = self.load_velocities(self.forward_velocity_filelist, frame_no)
 
@@ -979,10 +1105,8 @@ class OpFlowLab:
             Colormap to plot
         smoothing : int
             Size of gaussian smoothing kernel
-        colormap_min : float
-            Minimum value that will be used for colormap normalization
-        colormap_max : float
-            Maximum value that will be used for colormap normalization
+        colormap_min, colormap_max : float
+            Minimum and/or maximum value that is used to determine the normalization of the colormap
 
         Returns
         -------
@@ -991,9 +1115,9 @@ class OpFlowLab:
 
         See Also
         --------
-        plot_curl : wrapper function to plot curl for all frames
-        plot_divergence : wrapper function to plot divergence for all frames
-        plot_simple_shear : wrapper function to plot simple shear for all frames
+        flowCurl_function : wrapper function to plot curl for all frames
+        flowDivergence_function : wrapper function to plot divergence for all frames
+        flowShear_function : wrapper function to plot simple shear for all frames
         """
         _colormap = colormap_functions.parse_colormap(colormap)
 
@@ -1024,8 +1148,8 @@ class OpFlowLab:
 
             stat = output_image
             colormap_vis = colormap_functions.save_colorbar(_colormap,
-                                             filename = os.path.join(output_folder, "colorbar_{:03d}.png".format(frame_no)),
-                                             colormap_min=colormap_min, colormap_max=colormap_max,)
+                                                            filepath= os.path.join(output_folder, "colorbar_{:03d}.png".format(frame_no)),
+                                                            colormap_min=colormap_min, colormap_max=colormap_max, )
 
         return stat, colormap_vis
 
@@ -1044,17 +1168,15 @@ class OpFlowLab:
             Folder name that will be created in the main directory to store flow derivative images
         smoothing : int or Bool
             Sigma value for gaussian smoothing
-        colormap_min : float
-            Minimum value that will be used for colormap normalization
-        colormap_max : float
-            Maximum value that will be used for colormap normalization
+        colormap_min, colormap_max : float
+            Minimum and/or maximum value that is used to determine the normalization of the colormap
 
         Returns
         -------
 
         See Also
         --------
-        plot_stat_iter : base function to generate flow derivative images
+        flowDerivative_iteration : base function to generate flow derivative images
         """
         curl_folder = os.path.join(self.forward_velocity_folder, output_folder)
         os.makedirs(curl_folder, exist_ok=True)
@@ -1085,17 +1207,15 @@ class OpFlowLab:
             Folder name that will be created in the main directory to store flow derivative images
         smoothing : int or Bool
             Sigma value for gaussian smoothing
-        colormap_min : float
-            Minimum value that will be used for colormap normalization
-        colormap_max : float
-            Maximum value that will be used for colormap normalization
+        colormap_min, colormap_max : float
+            Minimum and/or maximum value that is used to determine the normalization of the colormap
 
         Returns
         -------
 
         See Also
         --------
-        plot_stat_iter : base function to generate flow derivative images
+        flowDerivative_iteration : base function to generate flow derivative images
         """
         divergence_folder = os.path.join(self.forward_velocity_folder, output_folder)
         os.makedirs(divergence_folder, exist_ok=True)
@@ -1126,17 +1246,15 @@ class OpFlowLab:
             Folder name that will be created in the main directory to store flow derivative images
         smoothing : int or Bool
             Sigma value for gaussian smoothing
-        colormap_min : float
-            Minimum value that will be used for colormap normalization
-        colormap_max : float
-            Maximum value that will be used for colormap normalization
+        colormap_min, colormap_max : float
+            Minimum and/or maximum value that is used to determine the normalization of the colormap
 
         Returns
         -------
 
         See Also
         --------
-        plot_stat_iter : base function to generate flow derivative images
+        flowDerivative_iteration : base function to generate flow derivative images
         """
         shear_folder = os.path.join(self.forward_velocity_folder, output_folder)
         os.makedirs(shear_folder, exist_ok=True)
