@@ -4,6 +4,23 @@ from numba import njit, prange
 
 
 def draw_tracer(image, centroids, color):
+    """
+    Draws tracers at the specified locations
+
+    Parameters
+    ----------
+    image : array
+        Image on which the tracers are drawn
+    centroids : array
+        Array containing the positions of tracers
+    color : array
+        Array containing the color information for each tracer
+
+    Returns
+    -------
+    image : array
+        Image containing the drawn tracers
+    """
     tracer_x = centroids[:, 1]
     tracer_y = centroids[:, 0]
 
@@ -15,6 +32,21 @@ def draw_tracer(image, centroids, color):
 
 @njit(parallel=True)
 def update_tracer(centroids, flow_y, flow_x):
+    """
+    Updates the position of the tracers using the velocity field
+
+    Parameters
+    ----------
+    centroids : array
+        Array containing the positions of tracers
+    flow_x, flow_y : array
+        Arrays containing the x and y components of the velocity field respectively
+
+    Returns
+    -------
+    output : array
+        Array containing the updated position of the tracers
+    """
     tracer_y = centroids[:, 0].copy()
     tracer_x = centroids[:, 1].copy()
 
